@@ -1,5 +1,7 @@
 import os, argparse
 from .template.template import get_license_str, get_framework, get_build_str, get_setup_str
+from .lib import write_file
+
 
 
 
@@ -10,25 +12,12 @@ def gen(name, template, root_dir, add_license):
         with open(os.path.join(root_dir, 'LICENSE'), 'w') as f:
             f.write(license)
 
-    if os.path.exists(os.path.join(root_dir, '.gitlab/build.yaml')):
-        build_str = get_build_str(template, name)
-        with open(os.path.join(root_dir, '.gitlab/build.yaml'), 'w') as f:
-            f.write(build_str)
-    if os.path.exists(os.path.join(root_dir, 'src/version.py')):
-        with open(os.path.join(root_dir, 'src/version.py'), 'w') as f:
-            f.write("__version__='0.0.1'")
-
-    if os.path.exists(os.path.join(root_dir, 'src/__init__.py')):
-        with open(os.path.join(root_dir, 'src/__init__.py'), 'w') as f:
-            f.write("from .version import __version__")
-
-    if os.path.exists(os.path.join(root_dir, '.gitignore')):
-        with open(os.path.join(root_dir, '.gitignore'), 'w') as f:
-            f.write("__pycache__\ndist\ndata\n*.egg-info\n.pypirc")
-
-    if os.path.exists(os.path.join(root_dir, '.gitlab-ci.yml')):
-        with open(os.path.join(root_dir, '.gitlab-ci.yml'), 'w') as f:
-            f.write("""
+    file_content_list = [
+        ['.gitlab/build.yaml', get_build_str(template, name)],
+        ['src/version.py', "__version__='0.0.1'"],
+        ['src/__init__.py', "from .version import __version__"],
+        ['.gitignore', '__pycache__\ndist\ndata\n*.egg-info\n.pypirc'],
+        ['.gitlab-ci.yml', """
 default:
   image: registry.cn-zhangjiakou.aliyuncs.com/wangxb/fastapi:vpc-control-test
 
@@ -40,7 +29,30 @@ stages:
 include:
   - local: '.gitlab/unit-test.yaml'
   - local: '.gitlab/build.yaml'
-            """)
+            """],
+        ['src/domain/repository/base.py', 
+         'from ddd_objects.domain.repository import Repository'],
+        ['src/infrastructure/repository_impl/base.py', 
+         'from ddd_objects.infrastructure.repository_impl import RepositoryImpl'],
+        ['src/infrastructure/converter/base.py', 
+         'from ddd_interface.infrastructure.converter import Converter'],
+        ['unit_test/test_repo.py', """
+import os, sys
+try:
+    import src
+except ImportError:
+    sys.path.append(os.getcwd())
+         """],
+        ['unit_test/test_ao.py', """
+import os, sys
+try:
+    import src
+except ImportError:
+    sys.path.append(os.getcwd())
+         """]
+    ]
+    for fn, s in file_content_list:
+        write_file(root_dir, fn, s)
 
 
 def ddd(args):
