@@ -37,9 +37,9 @@ def get_base_framework():
         ['src/infrastructure/ao/__init__.py', 'f'],
         ['src/infrastructure/do', 'd'],
         ['src/infrastructure/do/__init__.py', 'f'],
-        ['src/infrastructure/repository_impl.py', 'd'],
-        ['src/infrastructure/repository_impl.py/__init__.py', 'f'],
-        ['src/infrastructure/repository_impl.py/base.py', 'f'],
+        ['src/infrastructure/repository_impl', 'd'],
+        ['src/infrastructure/repository_impl/__init__.py', 'f'],
+        ['src/infrastructure/repository_impl/base.py', 'f'],
         ['unit_test/test_repo.py', 'f']
     ]
 
